@@ -16,13 +16,14 @@
 import os
 import io
 from hashlib import sha1
+from functools import wraps
 from collections import namedtuple
 from docutils import nodes
 from docutils.parsers import rst
 from docutils.parsers.rst.roles import set_classes
 from docutils.statemachine import ViewList
 
-from blockdiag.utils.bootstrap import create_fontmap
+from blockdiag.utils.bootstrap import create_fontmap, Application
 from blockdiag.utils.compat import string_types
 from blockdiag.utils.rst.nodes import blockdiag as blockdiag_node
 
@@ -46,6 +47,15 @@ def relfn2path(env, filename):
     return relfn, os.path.join(env.srcdir, relfn)
 
 
+def with_blockdiag(fn):
+    @wraps(fn)
+    def decorator(*args):
+        with Application():
+            return fn(*args)
+
+    return decorator
+
+
 def align(argument):
     align_values = ('left', 'center', 'right')
     return rst.directives.choice(argument, align_values)
@@ -142,6 +152,7 @@ class BlockdiagDirectiveBase(rst.Directive):
 class BlockdiagDirective(BlockdiagDirectiveBase):
     processor = None  # backward compatibility for 1.4.0
 
+    @with_blockdiag
     def run(self):
         figwidth = self.options.pop('figwidth', None)
         figclasses = self.options.pop('figclass', None)
